@@ -10,7 +10,7 @@ use vars qw($VERSION);
 
 my $format = '%#:%m%d';
 
-$VERSION = '1.16';
+$VERSION = '1.17';
 
 # Lifted from Date::Holidays::DE example: feiertage.pl
 # Ref: https://metacpan.org/source/MSCHMITT/Date-Holidays-DE-1.9/example/feiertage.pl
@@ -53,29 +53,43 @@ my %holiday_names = (
 sub holidays {
     my ($self, %params) = @_;
 
+    my $state = $params{'state'} ? $params{'state'} : ['all'];
+
+    use Data::Dumper;
+    print STDERR "We got state: ", Dumper $state;
+
+    my $holidays;
+
     if ( $params{'year'} ) {
-        $self->_transform_arrayref_to_hashref(
+        $holidays = $self->_transform_arrayref_to_hashref(
             Date::Holidays::DE::holidays(
                 YEAR   => $params{'year'},
                 FORMAT => $format,
+                WHERE  => $state,
             )
         );
     }
     else {
-        $self->_transform_arrayref_to_hashref(
+        $holidays = $self->_transform_arrayref_to_hashref(
             Date::Holidays::DE::holidays(
                 FORMAT => $format,
+                WHERE  => $state,
             )
         );
     }
+
+    return $holidays;
 }
 
 sub is_holiday {
     my ($self, %params) = @_;
 
+    my $state = $params{'state'} ? $params{'state'} : ['all'];
+
     my $holidays = Date::Holidays::DE::holidays(
         YEAR   => $params{'year'},
         FORMAT => $format,
+        WHERE  => $state,
     );
 
     my $holidays_hashref = $self->_transform_arrayref_to_hashref($holidays);
@@ -101,6 +115,8 @@ sub _transform_arrayref_to_hashref {
         $hashref_of_holidays->{$key} = $holiday_names{$shortname};
     }
 
+    print STDERR "We got state: ", Dumper $hashref_of_holidays;
+
     return $hashref_of_holidays;
 }
 
@@ -116,7 +132,7 @@ Date::Holidays::Adapter::DE - an adapter class for Date::Holidays::DE
 
 =head1 VERSION
 
-This POD describes version 1.16 of Date::Holidays::Adapter::DE
+This POD describes version 1.17 of Date::Holidays::Adapter::DE
 
 =head1 DESCRIPTION
 
@@ -147,6 +163,9 @@ B<countrycode> in the call to the constructor B<new>.
 The calendar will spand for a year and the keys consist of B<month> and B<day>
 concatenated.
 
+In addition from version 1.17 the adapter support the B<state> parameter, defaulting to
+B<'all'>.
+
 =head1 DIAGNOSTICS
 
 Please refer to DIAGNOSTICS in L<Date::Holidays>
@@ -186,7 +205,7 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 =head1 LICENSE AND COPYRIGHT
 
 L<Date::Holidays> and related modules are (C) by Jonas B. Nielsen, (jonasbn)
-2004-2018
+2004-2019
 
 Date-Holidays and related modules are released under the Artistic License 2.0
 
